pub struct KeystoreContainer(/* private fields */);Expand description
Construct a local keystore shareable container
Implementations
Sourceimpl KeystoreContainer
impl KeystoreContainer
Sourcepub fn new(config: &KeystoreConfig) -> Result<Self, Error>
pub fn new(config: &KeystoreConfig) -> Result<Self, Error>
Construct KeystoreContainer
Sourcepub fn keystore(&self) -> KeystorePtr
pub fn keystore(&self) -> KeystorePtr
Returns a shared reference to a dynamic Keystore trait implementation.
Sourcepub fn local_keystore(&self) -> Arc<LocalKeystore>
pub fn local_keystore(&self) -> Arc<LocalKeystore>
Returns a shared reference to the local keystore .